#
# spec file for package python-ipympl
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pyver   0.9.3
%define jsver   0.11.3
%bcond_with     test
Name:           python-ipympl
Version:        %{pyver}
Release:        11.1
Summary:        Matplotlib Jupyter Extension
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/matplotlib/ipympl
Source0:        https://files.pythonhosted.org/packages/py2.py3/i/ipympl/ipympl-%{pyver}-py2.py3-none-any.whl
Source1:        https://github.com/matplotlib/ipympl/raw/%{pyver}/docs/examples/full-example.ipynb
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module ipython < 9}
BuildRequires:  %{python_module ipython_genutils}
BuildRequires:  %{python_module ipywidgets >= 7.6.0 with %python-ipywidgets < 9}
BuildRequires:  %{python_module matplotlib >= 3.4.0 with %python-matplotlib < 4}
BuildRequires:  %{python_module matplotlib-web}
BuildRequires:  %{python_module nbval}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module traitlets < 6}
BuildRequires:  fdupes
BuildRequires:  jupyter-rpm-macros
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       jupyter-matplotlib = %{jsver}
Requires:       python-Pillow
Requires:       python-ipython < 9
Requires:       python-ipython_genutils
Requires:       python-matplotlib-web
Requires:       python-numpy
Requires:       python-traitlets < 6
Requires:       (python-ipywidgets >= 7.6.0 with python-ipywidgets < 9)
Requires:       (python-matplotlib >= 3.4.0 with python-matplotlib < 4)
Suggests:       python-jupyterlab
Suggests:       python-notebook
Provides:       python-jupyter_ipympl = %{pyver}
Obsoletes:      python-jupyter_ipympl < %{pyver}
BuildArch:      noarch
%python_subpackages

%description
Jupyter extension to display matplotlib plots in a widget.

This package provides the python interface.

%package     -n jupyter-matplotlib
Version:        %{jsver}
Summary:        Matplotlib Jupyter Extension
Group:          Development/Languages/Python
Requires:       jupyter-notebook
# Any flavor is okay, but suggest the primary one for automatic zypper choice -- boo#1214354
Requires:       python3dist(ipympl) = %{pyver}
Suggests:       python3-ipympl
Provides:       jupyter-ipympl = %{jsver}
Obsoletes:      jupyter-ipympl < %{jsver}

%description -n jupyter-matplotlib
Jupyter extension to display matplotlib plots in a widget.

This package provides the jupyter notebook extension.

%package     -n jupyter-matplotlib-jupyterlab
Version:        %{jsver}
Release:        11.1
Summary:        Matplotlib JupyterLab Extension
Group:          Development/Languages/Python
Requires:       jupyter-jupyterlab
# Any flavor is okay, but suggest the primary one for automatic zypper choice -- boo#1214354
Requires:       python3dist(ipympl) = %{pyver}
Suggests:       python3-ipympl
Provides:       jupyter-ipympl-jupyterlab = %{jsver}
Obsoletes:      jupyter-ipympl-jupyterlab < %{jsver}

%description -n jupyter-matplotlib-jupyterlab
Jupyter extension to display matplotlib plots in a widget.

This package provides the JupyterLab extension.

%prep
%setup -q -c ipympl-%{pyver} -D -T
%python_expand mkdir -p build; cp %{SOURCE0} build/
cp %{SOURCE1} .

%build
:

%install
%pyproject_install
%jupyter_move_config
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%fdupes %{buildroot}%{_jupyter_prefix}
cp %{buildroot}%{python3_sitelib}/ipympl-%{pyver}.dist-info/LICENSE .

%check
%pytest --nbval full-example.ipynb

%files %{python_files}
%license LICENSE
%{python_sitelib}/ipympl/
%{python_sitelib}/ipympl-%{pyver}.dist-info

%files -n jupyter-matplotlib
%license LICENSE
%{_jupyter_nbextension_dir}/jupyter-matplotlib
%{_jupyter_config} %{_jupyter_nb_notebook_confdir}/jupyter-matplotlib.json

%files -n jupyter-matplotlib-jupyterlab
%license LICENSE
%dir %{_jupyter_prefix}/labextensions
%{_jupyter_prefix}/labextensions/jupyter-matplotlib

%changelog
* Thu Aug 17 2023 Ben Greiner <code@bnavigator.de>
- Suggest primary python package -- boo#1214354
* Fri Apr 14 2023 Ben Greiner <code@bnavigator.de>
- Fix requirements
- Fix jsversion: 11.3
* Tue Apr  4 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.9.3
  * MNT: PEP 632 removed distutils by @tacaswell in #494
  * Make handle_binary compliant with the KernelMessage.IMessage
    spec by @mctoohey in #505
  * Ensure throttling does not break capture_scroll by @ianhi in
    [#478]
  * fix: add event modifiers for mpl 3.7 by @ianhi in #517
* Sun Oct  9 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update download path and name of full example
  * update required matplotlib version
- update to version 0.9.2:
  * Maintenance
    + Remove unused 'close' arg to show(). by @anntzer in #466
    + Move draw_if_interactive logic to
    new_figure_manager_given_figure. by @anntzer in #468
    + Add bot for updating galata screenshots by @martinRenou in #484
    + Add support for ipywidgets 8 by @ianhi in #461
- changes from version 0.9.1:
  * Fix issue with widget versioning that prevented ipympl to work in
    Voila, nbsphinx and vscode
  * update release instructions by @ianhi in #459
- changes from version 0.9.0:
  * Bump url-parse from 1.5.3 to 1.5.7 by @dependabot in #433
  * Create docs by @ianhi in #434
  * remove linting from tests - now in precommit by @ianhi in #444
  * fixed example notebook filepath by @lento234 in #445
  * update binder bot link by @ianhi in #447
  * support double click events by @ianhi in #446
  * use new matplotlib nightly wheel in tests by @ianhi in #449
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #452
  * add docs to readme by @ianhi in #453
  * Add model version separate from package version by @ianhi in #448
- changes from version 0.8.8:
  * fix toolbar for mpl>3.6 by @ianhi in #428
- changes from version 0.8.7:
  * Remove centering of plot on firefox by @ianhi in #421
  * Fix CI by @martinRenou in #423
- changes from version 0.8.6:
  * Use Retrolab on Binder by @martinRenou in #414
  * Allow ipython-8.0 by @stonebig in #418
- changes from version 0.8.5:
  * Fix package dependencies by @martinRenou in #410
* Fri Dec 24 2021 Ben Greiner <code@bnavigator.de>
- Update to v0.8.4 w/ jupyter-matplotlib v0.10.4
  * Try fixing the automatic release CI job by @martinRenou in #408
  * Improve toolbar positioning by @martinRenou in #407
- Release 0.8.3
  * Update CI badge for github actions by @ianhi in #384
  * Add configurable throttling for pan_zoom by @martinRenou in
    [#393]
  * Webpack: Remove docs build by @martinRenou in #394
  * Slow down pre-commit autoupdates by @ianhi in #398
  * Fix nbconvert pdf export by @martinRenou in #404
  * Refactor image embedding logic and fix nbconvert HTML export by
    @martinRenou in #406
  * Refactor toolbar by @martinRenou in #396
- Release 0.8.2
  * Fix issue with Pyolite workaround #382
- Release 0.8.1
  * Save plot image in the Widget model #376
  * Mock Tornado for JupyterLite #381
  * Fix DPI for static image #380
  * Improve rubberband #371
  * Pre-commit setup #362
  * Bug fixes:
  * Fix import when not in IPython context #364
- Release 0.8.0
  * ipympl now saves the static plot image in the Notebook #343
  * jupyter-matplotlib has switched to TypeScript #314
- Release 0.7.0
  * Added support improved keyhandling in matplotlib 3.4 #310
    (@tacaswell)
  * Update the integration with ipython #305 (@ianhi)
* Mon Mar  1 2021 Ben Greiner <code@bnavigator.de>
- Remove unused tarball source
* Fri Feb 26 2021 Ben Greiner <code@bnavigator.de>
- Update to v0.6.3 w/ labextension v0.8.3
  * Fix JupyterLab 2 support #296
  * Fix plt.pause() behaviour #291
- Release 0.6.0
  * Add support for JupyterLab 3
- Use the Wheel as it bundles the js stuff.
- Enable test with example notebook and pytest --nbval
- No requirement on jupyterlab or notebook: The user can decide
  how to use this widget with either or.
- Skip python36 build: python36-matplotlib is not available in TW
* Sat Sep 19 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * updated requirements (see setup.py)
- update to 0.5.8:
  * remove unnecessary traitlets
  * Update README.md
  * add jupyter keywords
  * Fix version table in README
  * Improve setup.py for fixing the Github "Used By" section
* Tue Jul 21 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 0.5.7
  * Add ESlint and prettier #213 by @QuLogic
  * Add versions table to the README #217 by @martinRenou
  * Add issue template #226 by @martinRenou
  * Add flake8 linting in CI #230 by @QuLogic
  * Add an option for prevent default behavior during scroll
    [#235] by @ianhi
  * Update dev install instructions #243 by @ianhi
  * Fix CSS issues in the toolbar icons #245 by @davidbailey00
- Update to 0.5.6
  * Missing "wait" cursor #205
  * Improved packaging for JupyterLab
- No changelog entries between 0.4.1 and 0.5.6
- labver is now 7.3.0
- remove Python 2 requirements
- require matplotlib web backend
* Mon Feb 24 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.4.1
  * Fix wheel
  * Fix binder badge, add travis/conda/npm badges
- Update to 0.4.0
  * Change the rate limiting to 60 fps.
  * Sync the widget layout interface with matplotlib
  * Only allow resizes after the original matplotlib figure
    has been created.
  * Change to "notebook"-like behavior
  * Rate limit text updates
  * Prevent the context menu from opening on right click.
  * Bump mixin-deep from 1.3.1 to 1.3.2 in /js
  * Bump lodash from 4.17.11 to 4.17.13 in /js
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Drop python2 support due to python-notebook dropping python2 support
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.3.3
  * Fixup jlab layout
  * Fix rubberband on Firefox
- Update to 0.3.2
  * Make use of CSS variables
- Update to 0.3.0
  * Use `display: block` for canvas elements and fix layout issues.
  * Resize support
  * Update to jupyterlab 1.0
  * Add support for changing button style
  * Center toolbar buttons
  * Fix Python inheritance
  * Make the figure a widget
  * Pan/Zoom toggle buttons
  * Move message in footer
  * js_version -> js_version
  * Interactive Toolbar widget
  * Remove jupyter.setDirty call
  * Send image data as binary buffer
  * Remove websocket proxy
  * Fix visual glitch when hiding the toolbar
  * Improve label CSS
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match python package naming guidelines.
- Split jupyter components into own subpackage.
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Use correct version number for jupyterlab subpackage.
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to 0.2.1
  * Use widget backend
  * Updated to use prefered methods for traitlets >= 4.1
* Wed Apr 25 2018 toddrme2178@gmail.com
- Update to version 0.1.1
  * Auto enable notebook extension
  * Fixup post-link
  * removing warnings from nbagg backend
* Thu Apr 19 2018 toddrme2178@gmail.com
- Switch to wheel for more reliable builds
* Mon Mar 12 2018 toddrme2178@gmail.com
- Initial version
